//=============================================================================
// Project:    SLP - An Interpreter for Super Logic Programs / Static Semantics
// Module:     unsafe.h
// Purpose:    Set of all unsafe variables in the current formula
// Last Change:29.09.2001
// Language:   C++
// Author:     Stefan Brass
// Email:      Stefan.Brass@informatik.uni-giessen.de, sbrass@sis.pitt.edu
// Address:    Universitaet Giessen, Arndtstr. 2, 35392 Giessen, Germany
// Copyright:  (c) 2000-2001 by Stefan Brass
// Licence:    Distributed under the conditions of the GNU Public Licence.
//=============================================================================

//=============================================================================
// Include File Frame:
//=============================================================================

#ifndef	UNSAFE_INCLUDED
#define UNSAFE_INCLUDED

//=============================================================================
// Used Types and Macros:
//=============================================================================

#ifndef VER_INCLUDED
#include "ver.h"
#endif

#ifndef BOOL_INCLUDED
#include "bool.h"
#endif

#ifndef CHECK_INCLUDED
#include "check.h"
#endif

#ifndef VAR_INCLUDED
#include "var.h"
#endif

//=============================================================================
// All variables in the current formula (class without instances):
//=============================================================================

class unsafe_c {

	public:

//-----------------------------------------------------------------------------
// Class Methods:
//-----------------------------------------------------------------------------

	// Reset (make variable list empty):
	static inline void reset(void)
		{ NumVars = 0; }

	// Add a Variable (if not already present):
	static void add_var(var_t var);

	// Check whether variable list is empty:
	static inline bool_t is_empty()
		{ CHECK(valid(), "unsafe_c::is_empty: Integrity violation");
		  return(NumVars == 0); }

	// Print variable list:
	static void print(void);

//-----------------------------------------------------------------------------
// Debugging Support:
//-----------------------------------------------------------------------------

#ifdef	VER_DEBUG
	// Integrity Check:
	public:
	static bool_t	valid(void);
#endif

//-----------------------------------------------------------------------------
// Private Members:
//-----------------------------------------------------------------------------

	private:

	// List of variables:
	static var_t	Vars[VER_MAX_VARS];

	// Number of variables in the list:
	static int	NumVars;

//-----------------------------------------------------------------------------
// End of Class:
//-----------------------------------------------------------------------------

};

//=============================================================================
// End of Include File:
//=============================================================================

#endif

